Peepal Web Framework
====================

Peepal is a minimalist python 3 web framework. 


Installation and Dependencies
-----------------------------

Install peepal with ``pip install peepal``. There are no dependencies other than the Python Standard Library.

